package
module
Version:
v0.0.0-...-c969036
Opens a new window with list of versions in this module.
Published: Dec 31, 2024
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
Pop an element from the stack in O(1) time.
Pop multiple elements from the stack in O(1) time.
func (s *Stack[T]) Push(v T)
Push an element onto the stack in O(1) time.
func (s *Stack[T]) Top() T
Peek at the top element of the stack in O(1) time.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.